"use strict";
exports.__esModule = true;
var $ = require("jquery");
require("jquery.growl");
var AvatarPreview = (function () {
    function AvatarPreview($element, options) {
        this.$element = $element;
        this.options = {
            accept: ["jpg", "png", "gif"],
            "delete": false,
            maxSize: 1024 * 1024
        };
        if (typeof options !== "undefined") {
            for (var option in options) {
                if (options.hasOwnProperty(option)) {
                    this.options[option] = options[option];
                }
            }
        }
        this.$preview = $("img.preview", $element);
        this.$file = $("input[type=file]", $element);
        this.run();
    }
    AvatarPreview.prototype.checkImageType = function (type) {
        switch (type) {
            case ("image/png"):
            case ("image/jpg"):
            case ("image/jpeg"):
            case ("image/gif"):
                return true;
        }
        return false;
    };
    AvatarPreview.prototype.run = function () {
        var _this = this;
        this.$preview.data("originalImage", this.$preview.attr("src"));
        this.$preview.data("backToDefault", true);
        var $btnRemove = $(".btn-remove", this.$element);
        if (!$btnRemove.data("default")) {
            $btnRemove.hide();
        }
        var that = this;
        $(".btn-upload", this.$element).on("click", function (e) {
            e.preventDefault();
            _this.$file.trigger("click");
        });
        $btnRemove.on("click", function (e) {
            e.preventDefault();
            if (!that.$preview.data("backToDefault")) {
                that.$preview.attr("src", that.$preview.data("originalImage"));
                that.$preview.data("backToOriginal", false);
                that.$file.val("");
                if (!$(this).data("default")) {
                    $(this).hide();
                }
                that.$preview.data("backToDefault", true);
            }
            else {
                var defaultImage = $(this).data("default");
                if (defaultImage) {
                    that.$file.val("");
                    that.$preview.attr("src", defaultImage);
                    var emptyInput = that.$file.attr("name") + "_remove";
                    if ($("input[name=" + emptyInput + "]", that.$element).length === 0) {
                        that.$element.append("<input type=\"hidden\" name=\"" + emptyInput + "\" value=\"1\" />");
                    }
                    $(this).hide();
                }
            }
        });
        this.$file.on("change", function () {
            if (this.files && this.files[0]) {
                var file = this.files[0];
                if (!that.checkImageType(file.type)) {
                    $.growl.error({ title: "خطا", message: "نوع این فایل معتبر نیست" });
                    return false;
                }
                if (file.size > that.options.maxSize) {
                    $.growl.error({ title: "خطا", message: "حجم این فایل بیشتر از حد تعیین شده است." });
                    return false;
                }
                var reader_1 = new FileReader();
                reader_1.onload = function (e) {
                    that.$preview.data("backToDefault", false);
                    $btnRemove.show();
                    that.$preview.attr("src", reader_1.result);
                };
                reader_1.readAsDataURL(this.files[0]);
                var emptyInput = that.$file.attr("name") + "_remove";
                var $emptyInput = $("input[name=" + emptyInput + "]", that.$element);
                if ($emptyInput.length) {
                    $emptyInput.remove();
                }
            }
        });
    };
    return AvatarPreview;
}());
exports.AvatarPreview = AvatarPreview;
